;; This model was created as part of a dissertation project, entitled "" by Sean Bergin
;; Please feel free to contact me with any questions at sean.m.bergin@gmail.com


extensions [gis matrix];; used to import maps that agents interact on

breed [start-points start-point]
breed [farmer-villages farmer-village]
breed[forager-band-bands forager-band]
undirected-link-breed [cap-links cap-link] ;; links used in the Capillary and Dual models which agriculture can spread across

farmer-villages-own[
  village-population     ;; number of people in a farmer village
  time-to-fission?       ;; true when population conditions necessitate that a new village must be created
  need-better-land?      ;; included for future expansion of the model to include environmental degredation
  active?                ;;
  ;;ocean-going?
  former-forager-band?
]

forager-band-bands-own[
 group-pop              ;; number of people in a forager group
 group-territory        ;; patches used as part of a forager group's territory
 years-of-contact       ;; number of years in which foragers have been in contact with farmers
]

patches-own [
  land-value         ;; value of a patch derived from the paleoenvironmental map
  suitable?          ;; true if a patch can be occupied
  occupied?          ;; true if a village or forager group is already on a patch
  color-scale        ;; color value for scaled coloring and bug workaround
  arrival-date       ;; year in which a patch is first occupied by a forager-agent
  coastal?           ;; true if a patch borders the ocen
  east-italy-coast?  ;; used to prevent maritime movement over the Italian peninsula instead of around it
  productivity       ;; *Experimental* could be used to add environmental degradation
  meso-prob          ;; *Experimental* could be used to better inform the location of forager groups with an input mesolithic probability map
  ]

globals [
  stopsim              ;; stops simulation
  landmap              ;; name of raster file of land for spreading (in ESRI ASCII format)
  basemap              ;; GIS base map for setting up world
  meso-map             ;; *Experimental* GIS map of mesolithic site locations used to locate mesolithic forager-band agents
  patch-size-km        ;; size of patches in real-earth units
  max-land-value       ;; maximum value of landscape
  min-land-value       ;; minimum value of landscape
  filebase             ;; spread type for base output file name
  leap-distance-km     ;; maximum leap distance km
  link-distance-km     ;; maximum link distance km
  coastal-leap-distance-km   ;; maximum leap distance along the coast km
  total-farmer-pop           ;;total number of farmers, for all villages, in a simulation
  dual-model-farmer-gather-interaction-radius-km ;;maximum distance in which famrers and foragers can interact in the dual model
  land

  max-farmer-per-patch;; maximum number of farmers per patch
  max-forager-band-bands-per-patch ;; max amount of a forager band that can occupy a patch. Usually multiple patches are needed for a forager band
  max-farmer-pop-density-km2 ;; maximum number of farmers per square km area
  max-forager-band-pop-density-km2 ;; maximum number of foragers per square km area
  farmer-fission-hh-size ;; the size of a new household created by fissioning from an existing one
  farmer-village-max-size ;; maximum size of a household on a given patch

  ]

to go

  let active-farmers farmer-villages with [active? = true]
  ;;active farmers are those that have a population and have somewhere to move to, this reduces the number of farmers that are moving


  if count active-farmers < 1 or (start-date - ticks) < end-date [ ;; end the simulation if everyone is dead or the time limit is passed
    if save-gis-output = true [
      ;; save the file
      let output-map gis:patch-dataset arrival-date
      let m-word word "_" simulation-map
      let t-word word "_" behaviorspace-run-number
      set t-word word t-word m-word
      let file-name word spread-type t-word
      gis:store-dataset output-map file-name
    ]
            stop
  ]

  ask active-farmers [farmer-subsistence]  ;; annual routine

  let land-less-farmers farmer-villages with [time-to-fission? = true] ;; not all farmers need to fission each year, so create a groupd of only those that need to fission

  ;; Choose the spread routine for the farmers and run it
  ask land-less-farmers [
    ifelse spread-type = "Wave of Advance"[spread-wave-of-advance]
    [ifelse spread-type = "Leap Frog" [spread-leap-frog farmer-fission-hh-size]
    [ifelse spread-type = "Maritime Pioneer Colonization"[spread-maritime-colonization farmer-fission-hh-size]
    [ifelse spread-type = "Dual Model"[spread-maritime-colonization farmer-fission-hh-size]
    [ifelse spread-type = "Capillary Diffusion"[spread-leap-frog farmer-fission-hh-size]
    []]]]]
    ]

  ;; farmer villages no longer need links with other farmers
  if spread-type ="Capillary Diffusion" or spread-type = "Dual Model"[ask farmer-villages [remove-farmer-links]]

  if forager-transitions = true [ ;;if foragers are capable of adopting agriculture
    ifelse spread-type = "Dual Model"
      ; Dual Model Transition
      [ask forager-band-bands [forager-band-change-subsistence-dual-model]]
      ;Generic forager-band Transition
      [ask forager-band-bands [forager-band-change-subsistence-generic]]
    ]

  tick ;; the annual cycle is over, Happy New Year!

end

to farmer-subsistence

 let people village-population
 let life-cycled 0

 ;;The birth and death rates are per capita. So there is a birth/death chance per person per year.
 while [life-cycled < people] [
  if random-float 100 + 1 < farmer-birth-rate [ set village-population village-population + 1 ]
  if random-float 100 + 1 < farmer-death-rate [ set village-population village-population - 1 ]
  set life-cycled life-cycled + 1
 ]

 if village-population > farmer-village-max-size and village-population > farmer-fission-hh-size[
   set time-to-fission? true
 ]
 ;; since the capillary model does not include fissioning as an essential mechanism, diffusion occurs on its own here
 if spread-type = "Capillary Diffusion"[ spread-capillary-model]

 if village-population < 1 [ set active? false]

end

to forager-band-subsistence
  let init-group-pop group-pop
  let life-cycled 0

 ;;The birth and death rates are per capita. So there is a birth/death chance per person per year.
 while [life-cycled < init-group-pop] [
  if random-float 100 + 1 < forager-birth-rate [ set group-pop group-pop + 1 ]
  if random-float 100 + 1 < forager-death-rate [ set group-pop group-pop - 1 ]
  set life-cycled life-cycled + 1
 ]


  ;;If the forager-band population changes, adjust the size of the group's territory
  if init-group-pop != group-pop [
    ask group-territory [set occupied? false set pcolor gray]
    set group-territory territory-calculator forager-group-size
    ask group-territory [ set occupied? true set pcolor 17]
    ]
   if group-pop < 1 [ set active? false]
end

to forager-band-change-subsistence-dual-model

  ; a counter with time inverse to chance of adoption
  let invader-count 0
  let farmer-interlopers farmer-villages in-radius dual-model-farmer-gather-interaction-radius-km
  let farmers-in-home-range count farmer-interlopers
  set invader-count invader-count + farmers-in-home-range

  ;Contact intensity is proportional to the number of farmers
  set years-of-contact   years-of-contact + invader-count

  ;;Annual contact will increase the probability of agricultural adoption
  if random-float 100 + 1 < years-of-contact
    [forager-band-change-subsistence]
  ;;Annual contact makes it possible for agriculture to spread to hunter-gatherer trading partners
  ;;Randomly choose one of link enighbors to start transitioning
  if random-float 100 + 1 < years-of-contact
    [forager-band-spread-through-networks]

end

to forager-band-spread-through-networks
    ;;spread agriculture through networks
    let trade-partners link-neighbors with [is-forager-band? self]
    let partner one-of trade-partners
    if partner != nobody[
       ask partner [ forager-band-change-subsistence ]
    ]
end

to forager-band-change-subsistence-generic
  ;;simple routine to make foragers change subsistence when there is a farmer nearby
  let invader-count 0
  ask group-territory [ set invader-count invader-count + count farmer-villages-on neighbors]

  if invader-count > forager-Neighbor-Transition-Threshold
  [forager-band-change-subsistence]

end

to remove-farmer-links
  ask link-neighbors [
    if is-farmer-village? self [ask link-with myself [die]]
  ]

end

to forager-band-change-subsistence

    ;; foragers change to farmers and spread out evenly in new villages in the land they previously occupied
    let this-forager-band-agent self
    ask patch-here [set occupied? false]
    ask group-territory [set occupied? false]
    let territory-patches count group-territory with [suitable? = true]
    let parent-link-neighbors link-neighbors

    ifelse territory-patches > 0 [
        let forager-band-per-patch group-pop / territory-patches
        set forager-band-per-patch round forager-band-per-patch
        let acculturation-count 0

        while [acculturation-count < territory-patches] [
          let new-farmstead-location one-of group-territory with [pcolor = 43 and suitable? = true]
          ask new-farmstead-location [set pcolor gray]

          ifelse  (territory-patches - acculturation-count) > 1
          [set group-pop group-pop - forager-band-per-patch]
          [set forager-band-per-patch group-pop]

          hatch-farmer-villages 1 [
             set village-population forager-band-per-patch
             set time-to-fission? false
             set need-better-land? false
             set former-forager-band? true
             set color red
             set size 1
             set shape "w and d2"
             set active? true
             move-to new-farmstead-location
             if spread-type = "Capillary Diffusion"[ask parent-link-neighbors [create-link-with myself [set hidden? hide-links]]]
             ask patch-here [set occupied? true
               if arrival-date = 0 [set arrival-date (start-date - ticks)]]
          ]
          set acculturation-count acculturation-count + 1
        ]
    ]
    [ ;; If no locations in a territory are usable for farming, move to a new location in leap-distance
       ask group-territory [set pcolor gray]
       let nearby-patches patches with [suitable? = true and occupied? = false]
       set nearby-patches nearby-patches with [distance myself <= leap-distance-km]
       let place-to-move max-one-of nearby-patches [land-value]
       let this-pop group-pop
       if place-to-move != nobody [
         hatch-farmer-villages 1 [
               set time-to-fission? false
               set need-better-land? false
               set color red
               set size 1
               set shape "w and d2"
               set active? true
               set former-forager-band? true
               set village-population this-pop
               move-to place-to-move
               if spread-type = "Capillary Diffusion"[ask parent-link-neighbors [create-link-with myself [set hidden? hide-links]]]
               ask patch-here [set occupied? true
                 if arrival-date = 0 [set arrival-date (start-date - ticks)]]
          ]
       ]
    ]

    die
end


;This method is used for the maritime spread
to spread-maritime-colonization [fission-pop]

  ifelse [coastal? = true] of patch-here[
     ifelse random-float 100 + 1 < maritime-movement-frequency [
           let littoral-patches nobody
       ; If the patch is in Italy, need to account for accidentally crossing Italy in maritime
            ifelse [east-italy-coast? = true] of patch-here
               [set littoral-patches  patches with [suitable? = true and occupied? = false and coastal? = true and east-italy-coast? = true and distance myself <= coastal-leap-distance-km]]
               [set littoral-patches  patches with [suitable? = true and occupied? = false and coastal? = true and distance myself <= coastal-leap-distance-km]]

            let place-to-move nobody
            ifelse consider-landscape
                [set place-to-move max-one-of littoral-patches [land-value]]
                [set place-to-move one-of littoral-patches]

            ;; Choose the places that can be moved to and create a village at the new location
            ifelse place-to-move != nobody [
              set village-population village-population - fission-pop
              set time-to-fission? false
              set need-better-land? false
              hatch 1 [
                  set village-population fission-pop
                  move-to place-to-move
                  ask patch-here [set occupied? true
                    if arrival-date = 0 [set arrival-date (start-date - ticks)]]
              ]
            ][
               ;
               spread-leap-frog fission-pop;; if unable to spread via maritime movement
              ]
     ][spread-leap-frog fission-pop] ;; if unable to spread via maritime movement

  ][spread-leap-frog fission-pop] ;if not on a littoral patch

end


to spread-capillary-model
  ;; capillary spread routine that uses network connections to spread agriculture to foragers
  let trade-partners link-neighbors with [is-forager-band? self]
  ;;if random chance - tell forager-band to transition
  ask trade-partners [
      if random 100 + 1 < capillary-spread-frequency
      [ forager-band-change-subsistence]
  ]
end


to spread-leap-frog [fission-pop]
  ;;leapfrog spread routine designed to enable movement to the best, unoccupied patch within range of a farmer agent
  let nearby-patches patches with [suitable? = true and occupied? = false and distance myself <= leap-distance-km ]
  let place-to-move nobody
  ifelse consider-landscape
  [set place-to-move max-one-of nearby-patches [land-value]]
  [set place-to-move one-of nearby-patches]

  ifelse place-to-move != nobody [
     set village-population village-population - fission-pop
     set time-to-fission? false
     hatch 1 [
           set village-population fission-pop
           move-to place-to-move
           ask patch-here [set occupied? true
             if arrival-date = 0 [set arrival-date (start-date - ticks)]]
     ]
  ]
 [ ;; if its not possible to move anywhere, don't fission and deactivate
   set   time-to-fission? false
   set   active? false
  ]

end


to spread-wave-of-advance
;; spread routine meant to implement the wave of advance spread, moving to contiguous unoccupied patches
  let nearby-patches neighbors with [suitable? = true and occupied? = false]
  let place-to-move nobody

  ifelse consider-landscape
  [set place-to-move max-one-of nearby-patches [land-value]]
  [set place-to-move one-of nearby-patches]

  ifelse place-to-move != nobody [
     set village-population village-population - farmer-fission-hh-size
     set time-to-fission? false
     hatch 1 [
           set village-population farmer-fission-hh-size
           move-to place-to-move
           ask patch-here [set occupied? true
             if arrival-date = 0 [set arrival-date (start-date - ticks)]]
     ]
  ]
 [ ; IF the household has no place to expand to:
   set   time-to-fission? false
   set   active? false
  ]
end


;;; ***************************************************************
;;; INITIALIZING PROCEDURES
;;; ***************************************************************


to setup
__clear-all-and-reset-ticks
  set stopsim false
  setup-world
  ;temp-start-import
  setup-startpoint x-start y-start
  setup-farmers
  setup-forager-band-bands

  set leap-distance-km  ((1 / patch-size-km) * leap-distance)
  set coastal-leap-distance-km  ((1 / patch-size-km) * coastal-leap-distance)
  set link-distance-km ((1 / patch-size-km) * forager-link-distance)


  if spread-type = "Capillary Diffusion" [
    let initial-farmer one-of farmer-villages
    ask initial-farmer [create-capillary-links]
    ask forager-band-bands [create-capillary-links]
  ]

  if spread-type = "Dual Model" [
    ask forager-band-bands [create-capillary-links]
    set dual-model-farmer-gather-interaction-radius-km ((1 / patch-size-km) * dual-model-farmer-gather-interaction-radius)
  ]

  reset-timer
end

to create-capillary-links
    let targets other forager-band-bands in-radius link-distance-km
    ifelse targets = nobody or count targets = 0 [
      ;; if there isn't someone to create a link with then try min distance to at least have one group to link to
      set targets min-one-of other forager-band-bands [distance myself]
      create-link-with targets[set hidden? hide-links]
      ][
      ;; if there is someone to create a link with.. then linking depending on the network configuration
      if network-model = "Random 1 Link Network"[ ask one-of targets [create-link-with myself [set hidden? hide-links]]]
      if network-model = "Random 5 Link Network"[
        ifelse count targets > 5[
          let counter 0
          while [counter < 5] [
            ask one-of targets [create-link-with myself [set hidden? hide-links]]
            set counter counter + 1
          ]
           ][ ;; if less than 5 just link to all available targets
           ask targets [create-link-with myself [set hidden? hide-links]]
           ]
        ]
      if network-model = "Nearest Neighbor 5 Link Network"[
        ifelse count targets > 5[
            set targets min-n-of 5 targets [distance myself]
            ask targets [create-link-with myself [set hidden? hide-links]]
           ][ ;; if less than 5 just link to all available targets
           ask targets [create-link-with myself [set hidden? hide-links]]
           ]
        ]
      if network-model = "Distance Network"[
        let furthest-forager-band one-of targets with-max [distance myself]
        let max-distance distance furthest-forager-band
        ask targets [
             if random max-distance + 1 > distance myself[
               create-link-with myself [set hidden? hide-links]
             ]
         ]
      ]
      if network-model = "Inverse Distance Network"[
        let furthest-forager-band one-of targets with-max [distance myself]
        let max-distance distance furthest-forager-band
        ask targets [
             if random max-distance + 1 < distance myself[
               create-link-with myself [set hidden? hide-links]
             ]
         ]
      ]

    ]
end

to setup-forager-band-bands

 ;;Determine the number of patches needed for a forager group and the number of forager band groups dependent upon the overall forager density

 ;;Values taken from Gregg 1988
 if forager-Strategy = "20% 80%" [set max-forager-band-pop-density-km2 0.5 ]
 if forager-Strategy = "50% 50%" [set max-forager-band-pop-density-km2 0.78 ]
 if forager-Strategy = "80% 20%" [set max-forager-band-pop-density-km2 1.72 ]
 if forager-Strategy = "Lower Density" [set max-forager-band-pop-density-km2 0.1]

 set max-forager-band-bands-per-patch max-forager-band-pop-density-km2 * (patch-size-km * patch-size-km)
 ;output-type max-forager-band-bands-per-patch output-print " forager-band-bands per patch"


  let land-need-per-forager-band-group round((forager-group-size / max-forager-band-bands-per-patch) - 1) ;; the -1 accounts for the patch the forager-band agent occupies
  if land-need-per-forager-band-group < 1 [set land-need-per-forager-band-group 1]
  let total-land count patches with [land-value > 0]
  let forager-band-occupied-count total-land * (forager-land / 100)
  ;The number of forager-band-bands created at the begining of the simulation is determined by a density value
  let forager-band-bands-to-start round (forager-band-occupied-count / land-need-per-forager-band-group)

  create-forager-band-bands forager-band-bands-to-start[
    set group-pop forager-group-size


   move-to one-of land with [occupied? = false]
    ifelse use-mesolithic-map [
      let places-to-move land with [occupied? = false and meso-prob = 1]
      ifelse places-to-move != nobody [
        move-to one-of places-to-move
      ][move-to one-of land with [occupied? = false]]]
    [move-to one-of land with [occupied? = false]]


    set color 104
    set size 2
    set shape "hunter-gatherer"
    ask patch-here [set occupied? true set pcolor 43]
    set years-of-contact 0

    ;inhabit the land around a forager-band and assign it to the forager-band group
    ;;assign that many neighboring patches to be occupied
       set group-territory territory-calculator forager-group-size
        ask group-territory [
        set occupied? true
        set pcolor 43
         ]
  ]


end


to setup-farmers
 ;;Values taken from Gregg 1988
 if Farmer-Strategy = " 100%     0%    0%     0%" [set max-farmer-pop-density-km2 121.95]
 if Farmer-Strategy = "62.5%  22.9%  2.8%  11.8%" [set max-farmer-pop-density-km2 3.41]
 if Farmer-Strategy = "  65%    25%    5%     5%" [set max-farmer-pop-density-km2 7.77]
 if Farmer-Strategy = "  70%    30%    0%     0%" [set max-farmer-pop-density-km2 7.82]

  set max-farmer-per-patch max-farmer-pop-density-km2 * (patch-size-km * patch-size-km)
  ;output-type max-farmer-per-patch output-print " farmers per patch"
  set farmer-village-max-size (farmer-fission-subsistence-capacity / 100) * max-farmer-per-patch
  ;output-type farmer-village-max-size output-print " farmer-village-max-size"
  set farmer-fission-hh-size farmer-village-max-size * (farmer-fissioning-proportion / 100)
  ;output-type farmer-fission-hh-size output-print " farmer fission size"

  create-farmer-villages 1 [setxy x-start y-start
    set village-population (int  max-farmer-per-patch)
    set time-to-fission? false
    set need-better-land? false
    set former-forager-band? false
    set color orange
    set size 1
    set shape "w and d2"
    set active? true
    ask patch-here [set occupied? true set arrival-date (start-date - ticks)]

  ]


end

to setup-world

  ;; set up world using GIS raster base map
  ;; adjust dimensions of NetLogo world to match match GIS raster base map aspect
  let world-wd 0
  let world-ht 0

  if simulation-map = "Slope Only" [set basemap gis:load-dataset "Maps and Data/neolithic_slope.grd"]
  if simulation-map = "Best Wheat Locations" [set basemap gis:load-dataset "Maps and Data/neolithic_wheat_index.grd"]
  if simulation-map = "Spring Precip Total" [set basemap gis:load-dataset "Maps and Data/neolithic_spring_precip_sum.grd"]
  if simulation-map = "Best Wheat & River Locations" [set basemap gis:load-dataset "Maps and Data/neolithic_wheat_index_rivers.grd"]
  if simulation-map = "Slope & Annual Avg Precip" [set basemap gis:load-dataset "Maps and Data/neolithic_slope_annual_precip.grd"]
  if simulation-map = "Slope & Rivers" [set basemap gis:load-dataset "Maps and Data/neolithic_slope_rivers.grd"]
  if simulation-map = "Best Wheat & River Locations 1km" [set basemap gis:load-dataset "Maps and Data/neolithic_wheat_index_rivers_1km.grd"]
  if simulation-map = "Best Wheat & Rivers Nulled" [set basemap gis:load-dataset "Maps and Data/neolithic_wheat_index_rivers_nulled.grd"]
  if simulation-map = "Minimum March Temps" [set basemap gis:load-dataset "Maps and Data/min_march.grd"]

  ;; Experimental addition - not tested
  if use-mesolithic-map[
   set meso-map gis:load-dataset "Maps and Data/mesolithic_locations.grd"
    ]

  let gis-wd gis:width-of basemap
  let gis-ht gis:height-of basemap
  ifelse gis-wd >= gis-ht
    [set world-wd world-max-dim
     set world-ht int (gis-ht * world-wd / gis-wd)]
    [set world-ht world-max-dim
     set world-wd int (gis-wd * world-ht / gis-ht)]
  resize-world 0 world-wd 0 world-ht
  gis:set-world-envelope (gis:envelope-union-of(gis:envelope-of basemap))
  gis:apply-raster basemap land-value

 if simulation-map = "Slope & Annual Avg Precip" [ask patches [set land-value land-value / 2]]

  if use-mesolithic-map[
   set meso-map gis:load-dataset "Maps and Data/mesolithic_locations.grd"
   gis:apply-raster meso-map meso-prob
    ]

  set max-land-value max [land-value] of patches with [not isNaN land-value]
  set min-land-value min [land-value] of patches with [not isNaN land-value]

   ask patches [ ifelse not isNAN land-value and land-value > land-value-minimum
     [set suitable? true set occupied? false ]
     [set suitable? false set occupied? false] ;set arrival-date "NaN"
     ]

  ;; determine size of patches in real-world units

  if GIS-grid-cell-km = "" or GIS-grid-cell-km <= 0 [set GIS-grid-cell-km 1] ;; if not specified, default to 1km raster grid cells
  set patch-size-km (gis-wd * GIS-grid-cell-km) / world-wd

  ;output-print "patch size = " output-type patch-size-km output-print " km in geographic units"

  ;; initialize unsuitable patch set (i.e., unsuitable for agriculture)
  let unsuitable patches with [suitable? = false]
  ask unsuitable [
    ifelse isNaN land-value ;; traps GIS NaN values
      [set pcolor blue set arrival-date -9999] ;; color patches corresponding to null value raster cells blue
      [set pcolor grey] ;; color ecologially unsuitable patches grey
    ]

  ;; initialize suitable patch set (i.e., suitable for agriculture)
  set land patches with [land-value > 0]
  ask land [set-shading]
  ask land [ set coastal? false set east-italy-coast? false]

  if coast-area = "Normal Coast" [ask land [if any? neighbors with [isNAN land-value] [set coastal? true]]  ]
  if coast-area = "Expanded Coast" [ask land [if any? neighbors with [any? neighbors with [isNAN land-value]] [set coastal? true]] ]

  ask land [ if pycor < 7 and pxcor < 354 [set coastal? false]]
  ask land [ if pycor > 202 and pxcor = 398 [set coastal? false]]
  ask land [ if pycor > 202 and pxcor = 397 [set coastal? false]]
  ask land [ if pycor > 221 and pxcor > 179 [set coastal? false]]
  ask land [ if pycor < 32 and pxcor < 13 [set coastal? false]]
  ask land [ if pycor > 200 and pxcor < 190 and pxcor > 120 [set coastal? false]]
  let coastal-locations land with [coastal? = true]
  ask coastal-locations [ if  pycor > 117 and pxcor > 395 [set east-italy-coast? true]]
  ask coastal-locations [ if  pycor > 89 and pxcor > 441 [set east-italy-coast? true]]
  ask coastal-locations [ if  pxcor > 459 and pycor > 52 [set east-italy-coast? true]]
  ask coastal-locations [ if  pxcor < 475 and pycor < 88 [set east-italy-coast? false]]
  ;ask land [if coastal? = true [set pcolor red]]
  ;ask land [if east-italy-coast? = true [set pcolor orange]]


end

to set-shading
  ;; scale color of suitable from dark (most suitable) to light
  carefully
    ;; this traps a potential bug
    [set pcolor scale-color green land-value (max-land-value + 1) (min-land-value)]
    [user-message "You need to run setup again"
    stop
    ]

end


to setup-startpoint [x y] ;;Initial farmer village is located on this point.
      ;;The point used was identified with radiocarbon evidence for the initial arrival of agriculture in southern Italy
      ask patch (x ) (y) [ ;; set start point for spread
        set occupied? true
      ]
      create-start-points 1 [  ;; create a turtle to mark start point for spread
        set color red
        set size 5
        set shape "x"
        setxy x y
      ]

end

to reset ;;Reset the simulation while keeping the map loaded.
  ask patches [set occupied? false]
  ask farmer-villages [die]
  ask forager-band-bands [die]
  ask start-points [die]
  let suitable patches with [suitable? = true]
  ask suitable [set-shading]
  set stopsim false
  reset-ticks
  clear-all-plots
  setup-startpoint x-start y-start ;; set up the previously selcted start points
  setup-farmers
  setup-forager-band-bands

    if spread-type = "Capillary Diffusion" [
    let initial-farmer one-of farmer-villages
    ask initial-farmer [create-capillary-links]
    ask forager-band-bands [create-capillary-links]
  ]

end


to-report territory-calculator [forager-band-group-pop]
  ;; routine used to identify the patches surrounding a forager that will be used as part of a forager group's territory
  let land-need round((forager-band-group-pop / max-forager-band-bands-per-patch) - 1) ;; the -1 accounts for the patch the forager-band agent occupies
  let need-more? true
  let territory-patches []
  let radius-size 3
  let range-total-area 60 ;; should be km2
  let forager-band-max-area range-total-area / (patch-size-km * patch-size-km) ;; max patch number
  let lands patches with [land-value > 0 ]

  while [need-more?] [
     set territory-patches lands in-radius radius-size with [occupied? = false]
     ifelse count territory-patches >= land-need
            [ set need-more? false]
            [set radius-size radius-size + 1]
  ]

  if count territory-patches > land-need [
   set territory-patches n-of land-need territory-patches
  ]

  report territory-patches
end


to-report geocoord-to-netlogo [geox geoy]
  ;; converts geographic coordinate pair to NetLogo coordinate pair in a list
  ;; with thanks to Eric Russell (GIS extension developer)

  let envelope gis:world-envelope ; [ xmin xmax ymin ymax ]
  let xscale (max-pxcor - min-pxcor) / (item 1 envelope - item 0 envelope)
  let yscale (max-pycor - min-pycor) / (item 3 envelope - item 2 envelope)
  let netlogo-x (geox - item 0 envelope) * xscale + min-pxcor
  let netlogo-y (geoy - item 2 envelope) * yscale + min-pycor

  report list netlogo-x netlogo-y
end

to-report isNaN [x]
  ;; routine to find NaN values
  report not ( x > 0 or x < 0 or x = 0 )
end


to calculate-farmer-pop
  ;used to calculate the entire number of farmers in a simulation
  let active-hhs farmer-villages with [active? = true]
  set total-farmer-pop 0

  ask active-hhs [set total-farmer-pop total-farmer-pop + village-population]

end

to-report calculate-forager-band-population-proportion
  let forager-band-descent farmer-villages with [former-forager-band? = true]
  report forager-band-descent / count (farmer-villages )
end




; Copyright Sean Bergin, Arizona State University, 2015.
@#$#@#$#@
GRAPHICS-WINDOW
5
90
1363
796
-1
-1
2.691
1
10
1
1
1
0
0
0
1
0
500
0
250
0
0
1
ticks
30.0

BUTTON
5
50
60
83
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
70
10
125
43
go once
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

CHOOSER
145
25
377
70
spread-type
spread-type
"Wave of Advance" "Leap Frog" "Maritime Pioneer Colonization" "Dual Model" "Capillary Diffusion"
3

BUTTON
70
50
125
83
Reset
reset
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
1140
830
1345
863
leap-distance
leap-distance
5
75
49
1
1
km
HORIZONTAL

INPUTBOX
1220
915
1275
975
world-max-dim
500
1
0
Number

INPUTBOX
1280
915
1347
975
GIS-grid-cell-km
0.5
1
0
Number

OUTPUT
970
1010
1350
1095
13

INPUTBOX
1110
915
1160
975
x-start
464
1
0
Number

INPUTBOX
1165
915
1215
975
y-start
104.5
1
0
Number

BUTTON
5
10
60
43
Setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
10
915
170
948
farmer-birth-rate
farmer-birth-rate
1
10
6.6
0.01
1
%
HORIZONTAL

SLIDER
10
950
170
983
farmer-death-rate
farmer-death-rate
1
10
4.8
0.01
1
%
HORIZONTAL

SLIDER
310
1060
595
1093
farmer-fission-subsistence-capacity
farmer-fission-subsistence-capacity
10
100
20
1
1
%
HORIZONTAL

SLIDER
10
985
170
1018
forager-birth-rate
forager-birth-rate
0.1
10
6
0.01
1
%
HORIZONTAL

SLIDER
10
1020
170
1053
forager-death-rate
forager-death-rate
0.1
10
5.8
0.01
1
%
HORIZONTAL

CHOOSER
650
25
788
70
Forager-Strategy
Forager-Strategy
"20% 80%" "50% 50%" "80% 20%" "Lower Density"
0

CHOOSER
795
25
997
70
Farmer-Strategy
Farmer-Strategy
" 100%     0%    0%     0%" "62.5%  22.9%  2.8%  11.8%" "  65%    25%    5%     5%" "  70%    30%    0%     0%"
1

TEXTBOX
650
70
800
88
%Plants %Hunting
9
0.0
1

TEXTBOX
800
70
970
91
%Crops %Herds %Plants %Hunting
9
0.0
1

SLIDER
10
845
215
878
forager-group-size
forager-group-size
5
50
30
1
1
NIL
HORIZONTAL

SLIDER
245
820
450
853
Forager-Neighbor-Transition-Threshold
Forager-Neighbor-Transition-Threshold
1
10
3
1
1
NIL
HORIZONTAL

SLIDER
10
880
215
913
forager-land
forager-land
0
20
1
1
1
% Inhabited
HORIZONTAL

SWITCH
1170
30
1327
63
save-gis-output
save-gis-output
1
1
-1000

SLIDER
860
910
1067
943
coastal-leap-distance
coastal-leap-distance
0
200
200
1
1
km
HORIZONTAL

SLIDER
860
830
1117
863
maritime-movement-frequency
maritime-movement-frequency
1
100
85
1
1
%
HORIZONTAL

CHOOSER
385
25
637
70
simulation-map
simulation-map
"Slope Only" "Best Wheat Locations" "Spring Precip Total" "Best Wheat & River Locations" "Slope & Annual Avg Precip" "Slope & Rivers" "Best Wheat & River Locations 1km" "Best Wheat & Rivers Nulled" "Minimum March Temps"
6

SWITCH
720
970
897
1003
forager-transitions
forager-transitions
0
1
-1000

SWITCH
540
970
717
1003
consider-landscape
consider-landscape
0
1
-1000

CHOOSER
860
865
1007
910
coast-area
coast-area
"Normal Coast" "Expanded Coast"
1

SLIDER
10
810
215
843
land-value-minimum
land-value-minimum
5
90
85
1
1
NIL
HORIZONTAL

INPUTBOX
1005
20
1090
80
start-date
6825
1
0
Number

INPUTBOX
1095
20
1160
80
end-date
4000
1
0
Number

SLIDER
575
915
780
948
forager-link-distance
forager-link-distance
5
200
105
5
1
km
HORIZONTAL

SWITCH
420
970
535
1003
hide-links
hide-links
0
1
-1000

CHOOSER
575
865
822
910
network-model
network-model
"Random 1 Link Network" "Random 5 Link Network" "Nearest Neighbor 5 Link Network" "Distance Network" "Inverse Distance Network"
4

SLIDER
240
860
555
893
dual-model-farmer-gather-interaction-radius
dual-model-farmer-gather-interaction-radius
1
100
10
1
1
km
HORIZONTAL

SWITCH
235
970
417
1003
use-mesolithic-map
use-mesolithic-map
1
1
-1000

TEXTBOX
245
805
395
823
DUAL MODEL
11
0.0
1

TEXTBOX
865
805
1015
823
MARITIME
11
0.0
1

TEXTBOX
575
805
725
823
CAPILLARY
11
0.0
1

SLIDER
10
1060
295
1093
farmer-fissioning-proportion
farmer-fissioning-proportion
0
100
50
1
1
% of household
HORIZONTAL

SLIDER
575
825
797
858
capillary-spread-frequency
capillary-spread-frequency
1
100
50
1
1
NIL
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

The purpose of this model is to provide a platform to test and compare multiple hypotheses for the spread of the Neolithic in the west Mediterranean.

## HOW IT WORKS

The model includes farmer village agents and forager band agents which occupy individual patches. Farmer agents found new agricultural villages (new Farmer Agents are created) when the population of a village reaches its carrying capacity or by random chance (dependent upon the model being tested). Forager agents may become farmer agents, a process which is initiated by different rules within a conceptual model. The agents are located on a GIS (Geographic Information System) based landscape which incorporates a map of the west Mediterranean (Italy, southern France, the Iberian peninsula and the northern coast of Africa). Multiple maps of environmental factors can be chosen at the onset of the simulation.  Farmer agents use the information from these maps to inform their choice of location for new agricultural villages. As the simulation progresses, farmer agents spread to new locations and the timing of the arrival of agriculturalists to a region is recorded. Once the simulation has ended the timing of agricultural arrival is compared to the arrival of agriculturalists as evidenced in the archaeological record. Through this process, multiple hypotheses of agricultural spread can be compared to one another and their relative success in explaining the spread of the Neolithic can be assessed.


### Models of Spread

The Wave of Advance - In this model farmers expand to neighboring patches based on population pressure.

Leapfrog Spread - In this model farmers expand to patches within a given radius based on population pressure.

Capillary Spread - In this model agriculture spreads along existing forager networks.

Maritime Pioneer Colonization - In this model farmers spread with a leapfrog spread and by way of long distance coastal movement.

The Dual Model - This spread model includes the Maritime spread model and includes Neolithic spread along networks similar to the Capillry model.


### Saving output
Optionally, the model will save a *.asc file of the study area which records the initial arrival time of farmers for each patch.




## COPYRIGHT AND LICENSE

Copyright 2016 Sean Bergin (Arizona State University)


This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 License.  To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-sa/3.0/ or send a letter to Creative Commons, 559 Nathan Abbott Way, Stanford, California 94305, USA.

## REFERENCES
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

boat 3
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6459832 true false 150 32 157 162
Polygon -13345367 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7500403 true true 158 37 172 45 188 59 202 79 217 109 220 130 218 147 204 156 158 156 161 142 170 123 170 102 169 88 165 62
Polygon -7500403 true true 149 66 142 78 139 96 141 111 146 139 148 147 110 147 113 131 118 106 126 71

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

hunter
false
0
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 105 90 60 195 90 210 135 105
Polygon -7500403 true true 195 90 270 135 255 165 165 105
Circle -6459832 true false 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Polygon -6459832 true false 120 90 105 90 180 195 180 165
Line -6459832 false 109 105 139 105
Line -6459832 false 122 125 151 117
Line -6459832 false 137 143 159 134
Line -6459832 false 158 179 181 158
Line -6459832 false 160 154 146 131
Rectangle -6459832 true false 120 193 180 201
Rectangle -6459832 true false 114 187 128 208
Rectangle -6459832 true false 177 187 191 208
Polygon -16777216 true false 225 30 255 75 270 120 270 150 255 195 225 240 255 210 270 195 285 150 285 120 270 75 225 30

hunter 2
false
0
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 105 90 60 195 90 210 135 105
Polygon -7500403 true true 195 90 270 135 255 165 165 105
Circle -6459832 true false 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Polygon -6459832 true false 120 90 105 90 180 195 180 165
Line -6459832 false 109 105 139 105
Line -6459832 false 122 125 151 117
Line -6459832 false 137 143 159 134
Line -6459832 false 158 179 181 158
Line -6459832 false 160 154 146 131
Rectangle -6459832 true false 120 193 180 201
Rectangle -6459832 true false 114 187 128 208
Rectangle -6459832 true false 177 187 191 208
Rectangle -6459832 true false 258 77 265 287
Polygon -16777216 true false 255 120 249 92 250 79 261 46 276 78 276 93 270 120 255 120

hunter-gatherer
false
0
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 105 90 60 195 90 210 135 105
Polygon -7500403 true true 195 90 270 135 255 165 165 105
Circle -6459832 true false 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Polygon -6459832 true false 120 90 105 90 180 195 180 165
Line -6459832 false 109 105 139 105
Line -6459832 false 122 125 151 117
Line -6459832 false 137 143 159 134
Line -6459832 false 158 179 181 158
Line -6459832 false 160 154 146 131
Rectangle -6459832 true false 120 193 180 201
Rectangle -6459832 true false 114 187 128 208
Rectangle -6459832 true false 177 187 191 208
Rectangle -6459832 true false 258 77 265 287
Polygon -16777216 true false 255 120 249 92 250 79 261 46 276 78 276 93 270 120 255 120
Polygon -6459832 true false 13 221 15 240 26 249 36 258 48 259 75 258 87 245 91 234 91 217 86 215
Polygon -6459832 true false 13 223 15 208 30 191 51 183 71 181 87 195 90 217 82 218 78 200 68 191 60 190 41 193 28 203 17 211 18 221

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

person soldier
false
0
Rectangle -7500403 true true 127 79 172 94
Polygon -10899396 true false 105 90 60 195 90 210 135 105
Polygon -10899396 true false 195 90 240 195 210 210 165 105
Circle -7500403 true true 110 5 80
Polygon -10899396 true false 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Polygon -6459832 true false 120 90 105 90 180 195 180 165
Line -6459832 false 109 105 139 105
Line -6459832 false 122 125 151 117
Line -6459832 false 137 143 159 134
Line -6459832 false 158 179 181 158
Line -6459832 false 146 160 169 146
Rectangle -6459832 true false 120 193 180 201
Polygon -6459832 true false 122 4 107 16 102 39 105 53 148 34 192 27 189 17 172 2 145 0
Polygon -16777216 true false 183 90 240 15 247 22 193 90
Rectangle -6459832 true false 114 187 128 208
Rectangle -6459832 true false 177 187 191 208

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

w and d house
false
0
Rectangle -6459832 true false 30 225 270 285
Rectangle -16777216 true false 120 240 180 285
Polygon -10899396 true false 15 225 150 165 285 225
Line -16777216 false 30 120 270 120
Line -10899396 false 45 285 45 225
Line -10899396 false 60 285 60 225
Line -10899396 false 75 285 75 225
Line -10899396 false 90 285 90 225
Line -10899396 false 105 285 105 225
Line -10899396 false 195 285 195 225
Line -10899396 false 210 285 210 225
Line -10899396 false 225 285 225 225
Line -10899396 false 240 285 240 225
Line -10899396 false 255 285 255 225
Line -7500403 true 151 167 45 224
Line -7500403 true 150 170 71 225
Line -7500403 true 152 165 104 221
Line -7500403 true 149 168 253 227
Line -7500403 true 150 167 227 225
Line -7500403 true 148 171 195 228
Line -7500403 true 149 169 149 222
Line -7500403 true 150 169 127 222
Line -7500403 true 147 168 169 223
Line -7500403 true 30 231 43 231
Line -7500403 true 31 238 43 238
Line -7500403 true 47 236 175 233
Line -7500403 true 34 247 113 249
Line -7500403 true 30 256 121 260
Line -7500403 true 32 271 109 274
Line -7500403 true 68 241 115 242
Line -7500403 true 65 268 119 264
Line -7500403 true 199 246 241 243
Line -7500403 true 183 256 266 249
Line -7500403 true 184 271 247 271
Line -7500403 true 177 230 266 233
Line -7500403 true 200 263 266 263
Line -7500403 true 207 278 266 277
Line -7500403 true 131 227 163 229

w and d2
false
0
Rectangle -6459832 true false 30 225 270 285
Rectangle -16777216 true false 120 240 180 285
Polygon -10899396 true false 15 225 150 165 285 225
Line -16777216 false 30 120 270 120
Line -10899396 false 45 285 45 225
Line -10899396 false 60 285 60 225
Line -10899396 false 75 285 75 225
Line -10899396 false 90 285 90 225
Line -10899396 false 105 285 105 225
Line -10899396 false 195 285 195 225
Line -10899396 false 210 285 210 225
Line -10899396 false 225 285 225 225
Line -10899396 false 240 285 240 225
Line -10899396 false 255 285 255 225
Line -7500403 true 30 231 43 231
Line -7500403 true 31 238 43 238
Line -7500403 true 47 236 175 233
Line -7500403 true 34 247 113 249
Line -7500403 true 30 256 121 260
Line -7500403 true 32 271 109 274
Line -7500403 true 68 241 115 242
Line -7500403 true 65 268 119 264
Line -7500403 true 199 246 241 243
Line -7500403 true 183 256 266 249
Line -7500403 true 184 271 247 271
Line -7500403 true 177 230 266 233
Line -7500403 true 200 263 266 263
Line -7500403 true 207 278 266 277
Line -7500403 true 131 227 163 229
Line -1 false 132 188 129 196
Line -1 false 100 198 82 206
Line -1 false 156 178 176 188
Line -1 false 144 191 155 214
Line -1 false 67 208 35 220
Line -1 false 111 196 107 210
Line -1 false 75 207 80 220
Line -1 false 203 197 216 209
Line -1 false 157 191 187 213
Line -1 false 137 201 112 219
Line -1 false 186 191 185 197
Line -1 false 148 171 133 178
Line -1 false 226 211 241 214
Line -1 false 191 206 201 218
Line -1 false 99 208 97 219
Line -1 false 124 184 108 186
Line -1 false 65 211 62 217
Line -1 false 166 205 170 216
Line -1 false 141 211 139 218
Line -1 false 252 219 258 219

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.3.1
@#$#@#$#@
setup
repeat 10 [ go ]
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="wave-of-advance-final-slope" repetitions="50" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;Lower Density&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Slope Only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="10"/>
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Wave of Advance&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.4"/>
      <value value="6.6"/>
      <value value="6.8"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-capillary-slope" repetitions="50" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="50"/>
      <value value="100"/>
      <value value="150"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Slope Only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
      <value value="&quot;50% 50%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-spread-uses-pop-pressure">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-spread-frequency">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Capillary Diffusion&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="1"/>
      <value value="25"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Inverse Distance Network&quot;"/>
      <value value="&quot;Random 5 Link Network&quot;"/>
      <value value="&quot;Nearest Neighbor 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-maritime-slope" repetitions="50" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Slope Only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Maritime Pioneer Colonization&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Inverse Distance Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="200"/>
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-dual-slope" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Slope Only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Dual Model&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Inverse Distance Network&quot;"/>
      <value value="&quot;Random 5 Link Network&quot;"/>
      <value value="&quot;Nearest Neighbor 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="total" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-spread-frequency">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Inverse Distance Network&quot;"/>
      <value value="&quot;Inverse Distance Network&quot;"/>
      <value value="&quot;Inverse Distance Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="25"/>
      <value value="50"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Slope Only&quot;"/>
      <value value="&quot;Slope Only&quot;"/>
      <value value="&quot;Slope Only&quot;"/>
      <value value="&quot;Slope Only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.6"/>
      <value value="6.4"/>
      <value value="6.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="100"/>
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="leap-distance">
      <value value="25"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;80% 20%&quot;"/>
      <value value="&quot;80% 20%&quot;"/>
      <value value="&quot;80% 20%&quot;"/>
      <value value="&quot;80% 20%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="25"/>
      <value value="50"/>
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-spread-uses-pop-pressure">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Capillary Diffusion&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="5"/>
      <value value="25"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-maritime-bw" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Best Wheat Locations&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Maritime Pioneer Colonization&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Inverse Distance Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="200"/>
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-dual-bw" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Best Wheat Locations&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Dual Model&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Inverse Distance Network&quot;"/>
      <value value="&quot;Random 5 Link Network&quot;"/>
      <value value="&quot;Nearest Neighbor 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-wave-of-advance-bw" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;Lower Density&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Best Wheat Locations&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="10"/>
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Wave of Advance&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.4"/>
      <value value="6.6"/>
      <value value="6.8"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-capillary-bw" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="50"/>
      <value value="100"/>
      <value value="150"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Best Wheat Locations&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
      <value value="&quot;50% 50%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-spread-uses-pop-pressure">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-spread-frequency">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Capillary Diffusion&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="1"/>
      <value value="25"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Inverse Distance Network&quot;"/>
      <value value="&quot;Random 5 Link Network&quot;"/>
      <value value="&quot;Nearest Neighbor 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-maritime-bwrl" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
      <value value="&quot;  65%    25%    5%     5%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Best Wheat &amp; River Locations&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Maritime Pioneer Colonization&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.6"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Inverse Distance Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="100"/>
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-dual-bwrl" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
      <value value="&quot;  65%    25%    5%     5%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Best Wheat &amp; River Locations&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Dual Model&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="1"/>
      <value value="3"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="25"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.6"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Random 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="100"/>
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-wave-bwrl" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;Lower Density&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Best Wheat &amp; River Locations&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Wave of Advance&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
      <value value="&quot;  65%    25%    5%     5%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-capillary-bwrl" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="25"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Best Wheat &amp; River Locations&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-spread-uses-pop-pressure">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-spread-frequency">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Capillary Diffusion&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.2"/>
      <value value="6.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Random 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-capillary-sp" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="25"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Spring Precip Total&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Capillary Diffusion&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.2"/>
      <value value="6.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Random 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-wave-sp" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;Lower Density&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Spring Precip Total&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Wave of Advance&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
      <value value="&quot;  65%    25%    5%     5%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-wave-slope-annual-precip" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;Lower Density&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Slope &amp; Annual Avg Precip&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Wave of Advance&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
      <value value="&quot;  65%    25%    5%     5%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-capillary-slope-annual-precip" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="25"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Slope &amp; Annual Avg Precip&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Capillary Diffusion&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.2"/>
      <value value="6.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Random 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-dual-slope-annual-precip" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
      <value value="&quot;  65%    25%    5%     5%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Slope &amp; Annual Avg Precip&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Dual Model&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="1"/>
      <value value="3"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="25"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.6"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Random 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="100"/>
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-dual-wheat-rivers-null" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
      <value value="&quot;  65%    25%    5%     5%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Best Wheat &amp; Rivers Nulled&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Dual Model&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="1"/>
      <value value="3"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="25"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.6"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Random 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="100"/>
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-maritime-wheat-rivers-null" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
      <value value="&quot;  65%    25%    5%     5%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Best Wheat &amp; Rivers Nulled&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Maritime Pioneer Colonization&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.6"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Inverse Distance Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="100"/>
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-maritime-slope-rivers" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
      <value value="&quot;  65%    25%    5%     5%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Slope &amp; Rivers&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Maritime Pioneer Colonization&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.6"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Inverse Distance Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="100"/>
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-dual-slope-rivers" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
      <value value="&quot;  65%    25%    5%     5%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Slope &amp; Rivers&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Dual Model&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="1"/>
      <value value="3"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="25"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.6"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Random 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="100"/>
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-capillary-slope-rivers" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="25"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Slope &amp; Rivers&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Capillary Diffusion&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.2"/>
      <value value="6.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Random 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-maritime-min-march" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
      <value value="&quot;  65%    25%    5%     5%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Minimum March Temps&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Maritime Pioneer Colonization&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.6"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Inverse Distance Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="100"/>
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-dual-min-march" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
      <value value="&quot;  65%    25%    5%     5%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Minimum March Temps&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Dual Model&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="1"/>
      <value value="3"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="25"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.6"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Random 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="100"/>
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-leapfrog-slope" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Slope Only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Leap Frog&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.5"/>
      <value value="6.6"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Random 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-dual-slope2" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Slope Only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Dual Model&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Random 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="100"/>
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-dual-bw2" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Best Wheat Locations&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Dual Model&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Random 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="100"/>
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-maritime-bw2" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Best Wheat Locations&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Maritime Pioneer Colonization&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6.6"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Inverse Distance Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="100"/>
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-maritime-slope2" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Slope Only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Maritime Pioneer Colonization&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6.6"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Inverse Distance Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="100"/>
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-maritime-noland" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Slope Only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Maritime Pioneer Colonization&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6.6"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Inverse Distance Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="100"/>
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-dual-noland" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Slope Only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Dual Model&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Random 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="100"/>
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-leapfrog-spring-precip" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Spring Precip Total&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Leap Frog&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.5"/>
      <value value="6.6"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Random 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-leapfrog-sap" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Slope &amp; Annual Avg Precip&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Leap Frog&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.5"/>
      <value value="6.6"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Random 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-leapfrog-bw" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Best Wheat Locations&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Leap Frog&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.5"/>
      <value value="6.6"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Random 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-leapfrog-bwrl" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Best Wheat &amp; River Locations&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Leap Frog&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.5"/>
      <value value="6.6"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Random 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-leapfrog-mm" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Minimum March Temps&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Leap Frog&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.5"/>
      <value value="6.6"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Random 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-capillary-mm" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="25"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Minimum March Temps&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Capillary Diffusion&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.2"/>
      <value value="6.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Random 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-wave-mm" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;Lower Density&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Minimum March Temps&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Wave of Advance&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
      <value value="&quot;  65%    25%    5%     5%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-capillary-none" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="25"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Minimum March Temps&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Capillary Diffusion&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.2"/>
      <value value="6.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Random 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-leapfrog-none" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Minimum March Temps&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Leap Frog&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.5"/>
      <value value="6.6"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Random 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="total -cap" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-spread-frequency">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Inverse Distance Network&quot;"/>
      <value value="&quot;Inverse Distance Network&quot;"/>
      <value value="&quot;Inverse Distance Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="25"/>
      <value value="50"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Slope Only&quot;"/>
      <value value="&quot;Slope Only&quot;"/>
      <value value="&quot;Slope Only&quot;"/>
      <value value="&quot;Slope Only&quot;"/>
      <value value="&quot;Slope Only&quot;"/>
      <value value="&quot;Slope Only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.6"/>
      <value value="6.4"/>
      <value value="6.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="leap-distance">
      <value value="25"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;80% 20%&quot;"/>
      <value value="&quot;80% 20%&quot;"/>
      <value value="&quot;80% 20%&quot;"/>
      <value value="&quot;80% 20%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="25"/>
      <value value="50"/>
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-spread-uses-pop-pressure">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Capillary Diffusion&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
      <value value="10"/>
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="total -wave" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-spread-frequency">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Inverse Distance Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Slope Only&quot;"/>
      <value value="&quot;Slope Only&quot;"/>
      <value value="&quot;Slope Only&quot;"/>
      <value value="&quot;Slope Only&quot;"/>
      <value value="&quot;Slope Only&quot;"/>
      <value value="&quot;Slope Only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.6"/>
      <value value="6.4"/>
      <value value="6.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="leap-distance">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;80% 20%&quot;"/>
      <value value="&quot;80% 20%&quot;"/>
      <value value="&quot;80% 20%&quot;"/>
      <value value="&quot;80% 20%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="25"/>
      <value value="50"/>
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-spread-uses-pop-pressure">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Capillary Diffusion&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="total -dual" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-spread-frequency">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Inverse Distance Network&quot;"/>
      <value value="&quot;Inverse Distance Network&quot;"/>
      <value value="&quot;Inverse Distance Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="25"/>
      <value value="50"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Slope Only&quot;"/>
      <value value="&quot;Slope Only&quot;"/>
      <value value="&quot;Slope Only&quot;"/>
      <value value="&quot;Slope Only&quot;"/>
      <value value="&quot;Slope Only&quot;"/>
      <value value="&quot;Slope Only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.6"/>
      <value value="6.4"/>
      <value value="6.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="leap-distance">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;80% 20%&quot;"/>
      <value value="&quot;80% 20%&quot;"/>
      <value value="&quot;80% 20%&quot;"/>
      <value value="&quot;80% 20%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="25"/>
      <value value="50"/>
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-spread-uses-pop-pressure">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Capillary Diffusion&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-capillary-slope2" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="25"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Slope Only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Capillary Diffusion&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.2"/>
      <value value="6.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Random 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-wave-slope2" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;Lower Density&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Slope Only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Wave of Advance&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
      <value value="&quot;  65%    25%    5%     5%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-capillary-bw2" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-link-distance">
      <value value="25"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Best Wheat Locations&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;20% 80%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hide-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Capillary Diffusion&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Neighbor-Transition-Threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maritime-movement-frequency">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capillary-spread-frequency">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dual-model-farmer-gather-interaction-radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="6.2"/>
      <value value="6.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network-model">
      <value value="&quot;Random 5 Link Network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coastal-leap-distance">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="final-wave-bw2" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count farmer-hhs with [former-forager? = true]</metric>
    <metric>count farmer-hhs</metric>
    <enumeratedValueSet variable="end-date">
      <value value="4000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-birth-rate">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-death-rate">
      <value value="5.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-value-minimum">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coast-area">
      <value value="&quot;Normal Coast&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-grid-cell-km">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Forager-Strategy">
      <value value="&quot;Lower Density&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-map">
      <value value="&quot;Best Wheat Locations&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="leap-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-africa">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-threshold">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fissioning-proportion">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-fission-subsistence-capacity">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="world-max-dim">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="start-date">
      <value value="6825"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spread-type">
      <value value="&quot;Wave of Advance&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-group-size">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y-start">
      <value value="104.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Farmer-Strategy">
      <value value="&quot;62.5%  22.9%  2.8%  11.8%&quot;"/>
      <value value="&quot;  65%    25%    5%     5%&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-land">
      <value value="1"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="save-gis-output">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-birth-rate">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farmer-death-rate">
      <value value="4.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="use-mesolithic-map">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="consider-landscape">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity-annual-decrease">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="x-start">
      <value value="464"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-transitions">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
1
@#$#@#$#@
